from .error import check_connection
import os
import random
from PIL import Image, ImageDraw, ImageFont, ImageFilter
from telegraph import upload_file

def logo(name):
    check_connection()
    try:
        TXTSTD = f"{name}"
        folder = "./resources/bgs"
        imgpath = random.choice(os.listdir(folder))
        bgfile = folder+'/'+imgpath
        folder2 = "./resources/animes"
        imgpath2 = random.choice(os.listdir(folder2))
        anmfile = folder2+'/'+imgpath2
        # open resources
        STDIMG = Image.open(bgfile)
        ANMIMG = Image.open(anmfile)
        FONTSTD = ImageFont.truetype("./resources/ROAD_RAGE.OTF", 170)
        x = STDIMG.width//2
        y = STDIMG.height//2
        STDIMG.paste(ANMIMG, ANMIMG)
        SHADOW = Image.new('RGBA', STDIMG.size)
        draw = ImageDraw.Draw(SHADOW)
        draw.text((640, 870), text=TXTSTD, fill='black', font=FONTSTD, anchor='mm', stroke_width=15, stroke_fill='black')
        SHADOW = SHADOW.filter(ImageFilter.BoxBlur(5))
        STDIMG.paste(SHADOW, SHADOW)
        EDITSTD = ImageDraw.Draw(STDIMG)
        EDITSTD.text((640, 870), TXTSTD, font=FONTSTD, anchor="mm", stroke_width=3, stroke_fill='black', fill='White')
        animestd = f'animebystd.jpg'
        STDIMG.save("animebystd.jpg")
        if os.path.exists(animestd):
           response = upload_file(animestd)
        os.remove(animestd)
        x = f"https://telegra.ph{response[0]}"
        info = {"logo" : x}
        return info
    except Exception as e:
        info = {"logo" : {e}}
        return info




from requests import get, exceptions


class NoInternetConnection(Exception):
    pass


class UnknownErrorOccurred(Exception):
    pass


class DeprecatedMethod(Exception):
    pass


def check_connection():
    try:
        get("https://www.google.com/")
    except (exceptions.ConnectionError, exceptions.Timeout):
        raise NoInternetConnection(
            "Your device hasn't connected to internet yet! Please turn on the internet connection to keep using pystlogo library!")



from setuptools import setup, find_packages

long_description = 'A Python package to generate simple logos'

reques = ['pillow', 'telegraph', 'requests']

setup(
  name='pystlogo',
  version='0.0.1',
  description='A Python package to generate simple logos',
  long_description=long_description,
  url='https://github.com/Sithijatd/pystlogo',  
  author='Sithijatd',
  author_email='Sithijatd@users.noreply.github.com',
  license='MIT', 
  classifiers = [
  'Development Status :: 5 - Production/Stable',
  'Intended Audience :: Education',
  'Operating System :: Microsoft :: Windows :: Windows 10',
  'License :: OSI Approved :: MIT License',
  'Programming Language :: Python :: 3',
  'Programming Language :: Python :: 3.4',
  'Programming Language :: Python :: 3.5',
  'Programming Language :: Python :: 3.6',
  'Programming Language :: Python :: 3.9',
  'Programming Language :: Python :: 3.10',
],
  keywords=['Telegram', 'python', 'logo', 'anime'], 
  packages=find_packages(),
  install_requires=reques
)
